@@ -7,7 +7,7 @@ package Lemonldap::NG::Portal::AuthMulti;
 
 use Lemonldap::NG::Portal::_Multi;    #inherits
 
-our $VERSION = '1.4.11';
+our $VERSION = '1.9.1';
 
 sub authInit {
     my $self = shift;
@@ -36,11 +36,6 @@ sub authFinish {
     return $self->_multi->try( 'authFinish', 0 );
 }
 
-sub authPostStore {
-    my $self = shift;
-    return $self->_multi->try( 'authPostStore', 0 );
-}
-
 sub authLogout {
     my $self = shift;
     return $self->_multi->try( 'authLogout', 0 );
@@ -48,18 +43,14 @@ sub authLogout {
 
 sub authForce {
     my $self = shift;
-    $self->_sub('authInit');
-    my $s    = $self->{_multi}->{last}->[0] . "::authForce";
-    return &{$s}($self);
+    return $self->_multi->try( 'authForce', 0 );
 }
 
 sub getDisplayType {
     my $self = shift;
-    return unless defined $self->{_multi}->{last};
     my $s    = $self->{_multi}->{last}->[0] . "::getDisplayType";
     return &{$s};
 }
 
-
 1;
 
